@@ -39,6 +39,17 @@ public:
   explicit LinGstDataDialog(QWidget *parent = 0);
   ~LinGstDataDialog();
 
+  // Retreive and store the duration:
+  void retrieveDuration(
+    GstElement *pipeline);
+
+  // Accessor function for duration:
+  gint64 getDuration() {return duration;}
+
+  // Always retrieve position, no need to store it:
+  gint64 retrievePosition(
+    GstElement *pipeline);
+
   int displayData(
     GstElement *pipeline);
 
@@ -51,8 +62,12 @@ public:
   void setAlbum(
     QString album);
 
+  void reset();
+
 private:
   Ui::LinGstDataDialog *ui;
+
+  gint64 duration;
 };
 
 #endif // LINGSTDATADIALOG_H
