@@ -51,7 +51,8 @@ public:
 
   void displayText(
     QString feedName,
-    QString textUrl);
+    QString textUrl,
+    bool openExternalBrowser);
 
 protected:
   void closeEvent(
