@@ -261,12 +261,12 @@ LinVideoDisplayForm::~LinVideoDisplayForm()
 
 
 void LinVideoDisplayForm::setProgram(
-  QString title,
+  QString feedName,
   QString mediaUrl)
 {
   if (gstreamerInUse) stopPlaying();
 
-//  ui->titleLabel->setText(title);
+  setWindowTitle(feedName);
 
 //  GstElement *xvsink = gst_element_factory_make("xvimagesink", "xvsink");
   xvsink = gst_element_factory_make("xvimagesink", "xvsink");
