@@ -29,10 +29,12 @@
 #include "linnowplayingform.h"
 #include "linvideodisplayform.h"
 #include "linhtmldisplayform.h"
+#include "linpreferencesform.h"
 #include "lindocumentationform.h"
 #include "linaboutform.h"
 #include "linnewsfeedwidgetitem.h"
 #include "linfilterdialog.h"
+#include "lindbus.h"
 #include <QXmlStreamReader>
 #include <QFile>
 #include <QString>
@@ -51,9 +53,10 @@ MainWindow::MainWindow(
     nowPlayingForm(0),
     videoDisplayForm(0),
     htmlDisplayForm(0),
+    preferencesForm(0),
     documentationForm(0),
-    aboutForm(0)
-//    filterDialog(0)
+    aboutForm(0),
+    dbus(0)
 {
   ui->setupUi(this);
 
@@ -71,9 +74,10 @@ MainWindow::MainWindow(
   nowPlayingForm = new LinNowPlayingForm(this);
   videoDisplayForm = new LinVideoDisplayForm(this);
   htmlDisplayForm = new LinHtmlDisplayForm(this, &qnam);
+  preferencesForm = new LinPreferencesForm(this);
   documentationForm = new LinDocumentationForm(this);
   aboutForm = new LinAboutForm(this);
-//  filterDialog = new LinFilterDialog(this);
+  dbus = new LinDBus();
 
   QSettings settings("pietrzak.org", "Linguine");
 
@@ -112,10 +116,12 @@ MainWindow::~MainWindow()
   if (nowPlayingForm) delete nowPlayingForm;
   if (videoDisplayForm) delete videoDisplayForm;
   if (htmlDisplayForm) delete htmlDisplayForm;
+  if (preferencesForm) delete preferencesForm;
   if (documentationForm) delete documentationForm;
   if (aboutForm) delete aboutForm;
-//  if (filterDialog) delete filterDialog;
   if (flickableTabBar) delete flickableTabBar;
+  if (dbus) delete dbus;
+
   delete ui;
 }
 
@@ -519,39 +525,54 @@ void MainWindow::on_mediaListWidget_itemActivated(QListWidgetItem *item)
 
   if (media == Audio_Media)
   {
-    // Make sure the other form isn't playing:
-    videoDisplayForm->stopPlaying();
+    if (preferencesForm->openExternalPlayer())
+    {
+      dbus->launchMedia(nwi->getMediaUrl());
+    }
+    else
+    {
+      // Make sure the other form isn't playing:
+      videoDisplayForm->stopPlaying();
 
-    nowPlayingForm->setProgram(
-      nwi->getName(),
-      nwi->getImage(),
-      nwi->getItemTitle(),
-      nwi->getMediaUrl());
+      nowPlayingForm->setProgram(
+        nwi->getName(),
+        nwi->getImage(),
+        nwi->getItemTitle(),
+        nwi->getMediaUrl());
 
-    nowPlayingForm->show();
+      nowPlayingForm->show();
+    }
   }
   else if (media == Video_Media)
   {
-    // Make sure the other form isn't playing:
-    nowPlayingForm->stopPlaying();
+    if (preferencesForm->openExternalPlayer())
+    {
+      dbus->launchMedia(nwi->getMediaUrl());
+    }
+    else
+    {
+      // Make sure the other form isn't playing:
+      nowPlayingForm->stopPlaying();
 
-    videoDisplayForm->setProgram(
-      nwi->getName(),
-      nwi->getMediaUrl());
+      videoDisplayForm->setProgram(
+        nwi->getName(),
+        nwi->getMediaUrl());
 
-    // Set auto orientation to false:
-    setAttribute(static_cast<Qt::WidgetAttribute>(130), false);
+      // Set auto orientation to false:
+      setAttribute(static_cast<Qt::WidgetAttribute>(130), false);
 
-    // Set landscape orientation to true:
-    setAttribute(static_cast<Qt::WidgetAttribute>(129), true);
+      // Set landscape orientation to true:
+      setAttribute(static_cast<Qt::WidgetAttribute>(129), true);
 
-    videoDisplayForm->show();
+      videoDisplayForm->show();
+    }
   }
   else if (media == Text_Media)
   {
     htmlDisplayForm->displayText(
       nwi->getName(),
-      nwi->getSourceUrl());
+      nwi->getSourceUrl(),
+      preferencesForm->openExternalBrowser());
 
     htmlDisplayForm->show();
   }
@@ -617,6 +638,12 @@ void MainWindow::on_actionReset_Newsfeeds_triggered()
 }
 
 
+void MainWindow::on_actionPreferences_triggered()
+{
+  preferencesForm->show();
+}
+
+
 void MainWindow::on_actionDocumentation_triggered()
 {
   documentationForm->show();
