@@ -34,10 +34,11 @@ class LinHtmlDisplayForm;
 class QListWidgetItem;
 class LinNewsfeedWidgetItem;
 class QXmlStreamReader;
+class LinPreferencesForm;
 class LinDocumentationForm;
 class LinAboutForm;
 class QSettings;
-//class LinFilterDialog;
+class LinDBus;
 
 namespace Ui {
   class MainWindow;
@@ -85,6 +86,7 @@ private slots:
   void on_actionManage_Categories_triggered();
   void on_actionLoad_Newsfeeds_File_triggered();
   void on_actionReset_Newsfeeds_triggered();
+  void on_actionPreferences_triggered();
   void on_actionDocumentation_triggered();
   void on_actionAbout_triggered();
 
@@ -124,9 +126,10 @@ private:
   LinNowPlayingForm *nowPlayingForm;
   LinVideoDisplayForm *videoDisplayForm;
   LinHtmlDisplayForm *htmlDisplayForm;
+  LinPreferencesForm *preferencesForm;
   LinDocumentationForm *documentationForm;
   LinAboutForm *aboutForm;
-//  LinFilterDialog *filterDialog;
+  LinDBus *dbus;
 
   QNetworkAccessManager qnam;
 
